@@ -87,7 +87,7 @@ lou_registerLogCallback(logcallback callback) {
 		logCallbackFunction = callback;
 }
 
-static logLevels logLevel = LOG_INFO;
+static logLevels logLevel = LOU_LOG_INFO;
 void EXPORT_CALL
 lou_setLogLevel(logLevels level) {
 	logLevel = level;
