@@ -85,6 +85,13 @@ to stderr.\n\n",
 #ifdef HAVE_LIBYAML
 #include <yaml.h>
 
+typedef struct {
+	const char *name;
+	const char *content;  // table content in case of an inline table; NULL means name is
+						  // a file
+	int location;		  // location in YAML file (line number) where table is defined
+} table_value;
+
 const char *event_names[] = { "YAML_NO_EVENT", "YAML_STREAM_START_EVENT",
 	"YAML_STREAM_END_EVENT", "YAML_DOCUMENT_START_EVENT", "YAML_DOCUMENT_END_EVENT",
 	"YAML_ALIAS_EVENT", "YAML_SCALAR_EVENT", "YAML_SEQUENCE_START_EVENT",
@@ -100,6 +107,8 @@ int errors = 0;
 int count = 0;
 
 static char const **emph_classes = NULL;
+static table_value *display_table = NULL;
+static int new_table = 0;
 
 static void
 simple_error(const char *msg, yaml_parser_t *parser, yaml_event_t *event) {
@@ -162,16 +171,58 @@ read_table_query(yaml_parser_t *parser, const char **table_file_name_check) {
 	return query_as_string;
 }
 
-static char *
-read_table(yaml_event_t *start_event, yaml_parser_t *parser, const char *display_table) {
-	char *table = NULL;
-	if (start_event->type != YAML_SCALAR_EVENT ||
-			strcmp((const char *)start_event->data.scalar.value, "table"))
-		return 0;
+static void
+compile_inline_table(const char *table_name, const char *table_content, int location) {
+	char *p = (char *)table_content;
+	char *line_start = p;
+	int line_len = 0;
+	while (*p) {
+		if (*p == 10 || *p == 13) {
+			char *line = strndup((const char *)line_start, line_len);
+			if (!lou_compileString(table_name, line))
+				error_at_line(EXIT_FAILURE, 0, file_name, location, "Error in table %s",
+						table_name);
+			location++;
+			free(line);
+			line_start = p + 1;
+			line_len = 0;
+		} else {
+			line_len++;
+		}
+		p++;
+	}
+}
 
-	table = malloc(sizeof(char) * MAXSTRING);
-	table[0] = '\0';
+static void
+compile_include(const char *table_name, const char *tableList, int location) {
+	char *p;
+	char *includeRule = malloc(sizeof(char) * MAXSTRING);
+	char *subTable;
+	subTable = strdup(tableList);
+	p = subTable;
+	while (*p != '\0') {
+		char *subTable = p;
+		while (*p != '\0' && *p != ',') p++;
+		if (*p == ',') {
+			*p = '\0';
+			p++;
+		}
+		sprintf(includeRule, "include %s", subTable);
+		if (!lou_compileString(table_name, includeRule))
+			error_at_line(EXIT_FAILURE, 0, file_name, location, "Error in table %s",
+					table_name);
+	}
+	free(includeRule);
+	free(subTable);
+}
+
+static table_value *
+read_table_value(yaml_parser_t *parser, int start_line) {
+	table_value *table;
+	char *table_name = malloc(sizeof(char) * MAXSTRING);
+	char *table_content = NULL;
 	yaml_event_t event;
+	table_name[0] = '\0';
 	if (!yaml_parser_parse(parser, &event) ||
 			!(event.type == YAML_SEQUENCE_START_EVENT ||
 					event.type == YAML_SCALAR_EVENT ||
@@ -183,7 +234,7 @@ read_table(yaml_event_t *start_event, yaml_parser_t *parser, const char *display
 	if (event.type == YAML_SEQUENCE_START_EVENT) {
 		yaml_event_delete(&event);
 		int done = 0;
-		char *p = table;
+		char *p = table_name;
 		while (!done) {
 			if (!yaml_parser_parse(parser, &event)) {
 				yaml_parse_error(parser);
@@ -191,15 +242,12 @@ read_table(yaml_event_t *start_event, yaml_parser_t *parser, const char *display
 			if (event.type == YAML_SEQUENCE_END_EVENT) {
 				done = 1;
 			} else if (event.type == YAML_SCALAR_EVENT) {
-				if (table != p) strcat(p++, ",");
+				if (table_name != p) strcat(p++, ",");
 				strcat(p, (const char *)event.data.scalar.value);
 				p += event.data.scalar.length;
 			}
 			yaml_event_delete(&event);
 		}
-		if (!lou_getTable(table))
-			error_at_line(EXIT_FAILURE, 0, file_name, start_event->start_mark.line + 1,
-					"Table %s not valid", table);
 	} else if (event.type == YAML_SCALAR_EVENT) {
 		yaml_char_t *p = event.data.scalar.value;
 		if (*p)
@@ -208,24 +256,10 @@ read_table(yaml_event_t *start_event, yaml_parser_t *parser, const char *display
 			// If the scalar ends with a newline, assume it is a block
 			// scalar, so treat as an inline table. (Is there a proper way
 			// to check for a block scalar?)
-			sprintf(table, "%s%d", inline_table_prefix, start_event->start_mark.line + 1);
-			p = event.data.scalar.value;
-			yaml_char_t *line_start = p;
-			int line_len = 0;
-			while (*p) {
-				if (*p == 10 || *p == 13) {
-					char *line = strndup((const char *)line_start, line_len);
-					lou_compileString(table, line);
-					free(line);
-					line_start = p + 1;
-					line_len = 0;
-				} else {
-					line_len++;
-				}
-				p++;
-			}
+			sprintf(table_name, "%s%d", inline_table_prefix, start_line);
+			table_content = strdup((const char *)event.data.scalar.value);
 		} else {
-			strcat(table, (const char *)event.data.scalar.value);
+			strcat(table_name, (const char *)event.data.scalar.value);
 		}
 		yaml_event_delete(&event);
 	} else {  // event.type == YAML_MAPPING_START_EVENT
@@ -233,37 +267,83 @@ read_table(yaml_event_t *start_event, yaml_parser_t *parser, const char *display
 		const char *table_file_name_check = NULL;
 		yaml_event_delete(&event);
 		query = read_table_query(parser, &table_file_name_check);
-		table = lou_findTable(query);
+		table_name = lou_findTable(query);
 		free(query);
-		if (!table)
-			error_at_line(EXIT_FAILURE, 0, file_name, start_event->start_mark.line + 1,
+		if (!table_name)
+			error_at_line(EXIT_FAILURE, 0, file_name, start_line,
 					"Table query did not match a table");
 		if (table_file_name_check) {
-			const char *table_file_name = table;
+			const char *table_file_name = table_name;
 			do {
 				table_file_name++;
 			} while (*table_file_name);
-			while (table_file_name >= table && *table_file_name != '/' &&
+			while (table_file_name >= table_name && *table_file_name != '/' &&
 					*table_file_name != '\\')
 				table_file_name--;
 			if (strcmp(table_file_name_check, table_file_name + 1))
-				error_at_line(EXIT_FAILURE, 0, file_name,
-						start_event->start_mark.line + 1,
+				error_at_line(EXIT_FAILURE, 0, file_name, start_line,
 						"Table query did not match expected table: expected '%s' but got "
 						"'%s'",
 						table_file_name_check, table_file_name + 1);
 		}
 	}
+	table = malloc(sizeof(table_value));
+	table->name = table_name;
+	table->content = table_content;
+	table->location = start_line + 1;
+	return table;
+}
+
+static void
+free_table_value(table_value *table) {
+	if (table) {
+		free((char *)table->name);
+		if (table->content) free((char *)table->content);
+		free(table);
+	}
+}
+
+static char *
+read_table(yaml_event_t *start_event, yaml_parser_t *parser) {
+	table_value *table = NULL;
+	char *table_name = NULL;
+	if (start_event->type != YAML_SCALAR_EVENT ||
+			strcmp((const char *)start_event->data.scalar.value, "table"))
+		return 0;
+	table = read_table_value(parser, start_event->start_mark.line + 1);
+	table_name = strdup((char *)table->name);
 	if (display_table) {
-		char *t = table;
-		table = malloc(strlen(display_table) + 1 + strlen(t) + 1);
-		strcpy(table, display_table);
-		strcat(table, ",");
-		strcat(table, t);
+		char *t = table_name;
+		table_name = malloc(strlen(display_table->name) + 1 + strlen(t) + 1);
+		strcpy(table_name, display_table->name);
+		strcat(table_name, ",");
+		strcat(table_name, t);
 		free(t);
 	}
-	emph_classes = lou_getEmphClasses(table);  // get declared emphasis classes
-	return table;
+	new_table = 0;
+	if (!lou_getTable(table_name))
+		error_at_line(EXIT_FAILURE, 0, file_name, start_event->start_mark.line + 1,
+				"Table %s not valid", table_name);
+	// trick to find out whether it is the first time this table is compiled
+	if (new_table) {
+		if (table->content || (display_table && display_table->content)) {
+			if (display_table) {
+				if (display_table->content)
+					compile_inline_table(
+							table_name, display_table->content, display_table->location);
+				else
+					compile_include(
+							table_name, display_table->name, display_table->location);
+			}
+			if (table->content)
+				compile_inline_table(table_name, table->content, table->location);
+			else
+				compile_include(table_name, table->name, table->location);
+		}
+	}
+	free_table_value(table);
+	emph_classes = lou_getEmphClasses(table_name);  // get declared emphasis classes
+	return table_name;
 }
 
 static void
@@ -799,8 +879,14 @@ read_tests(yaml_parser_t *parser, char **tables, int direction, int hyphenation)
 static char **
 customTableResolver(const char *tableList, const char *base) {
 	static char *dummy_table[1];
-	if (strncmp(tableList, inline_table_prefix, strlen(inline_table_prefix)) == 0)
-		return dummy_table;
+	char *p = (char *)tableList;
+	new_table = 1;
+	while (*p != '\0') {
+		if (strncmp(p, inline_table_prefix, strlen(inline_table_prefix)) == 0)
+			return dummy_table;
+		while (*p != '\0' && *p != ',') p++;
+		if (*p == ',') p++;
+	}
 	return _lou_defaultTableResolver(tableList, base);
 }
 
@@ -915,14 +1001,9 @@ main(int argc, char *argv[]) {
 	int has_next;
 	has_next = yaml_parser_parse(&parser, &event);
 
-	const char *display_table = NULL;
 	if (has_next && event.type == YAML_SCALAR_EVENT &&
 			!strcmp((const char *)event.data.scalar.value, "display")) {
-		yaml_event_delete(&event);
-		if (!yaml_parser_parse(&parser, &event) || event.type != YAML_SCALAR_EVENT)
-			yaml_error(YAML_SCALAR_EVENT, &event);
-		display_table =
-				strndup((const char *)event.data.scalar.value, event.data.scalar.length);
+		display_table = read_table_value(&parser, event.start_mark.line + 1);
 		yaml_event_delete(&event);
 		has_next = yaml_parser_parse(&parser, &event);
 	}
@@ -931,7 +1012,7 @@ main(int argc, char *argv[]) {
 
 	int MAXTABLES = 150;
 	char *tables[MAXTABLES + 1];
-	while ((tables[0] = read_table(&event, &parser, display_table))) {
+	while ((tables[0] = read_table(&event, &parser))) {
 		yaml_event_delete(&event);
 		int k = 1;
 		while (1) {
@@ -939,7 +1020,7 @@ main(int argc, char *argv[]) {
 				error_at_line(EXIT_FAILURE, 0, file_name, event.start_mark.line + 1,
 						"Expected table or %s (actual %s)",
 						event_names[YAML_SCALAR_EVENT], event_names[event.type]);
-			if ((tables[k++] = read_table(&event, &parser, display_table))) {
+			if ((tables[k++] = read_table(&event, &parser))) {
 				if (k == MAXTABLES)
 					error_at_line(EXIT_FAILURE, 0, file_name, event.start_mark.line + 1,
 							"Only %d tables in one YAML test supported", MAXTABLES);
@@ -1004,6 +1085,7 @@ main(int argc, char *argv[]) {
 	yaml_parser_delete(&parser);
 
 	free(emph_classes);
+	free_table_value(display_table);
 	lou_free();
 
 	assert(!fclose(file));
